as_thread

Function as_thread 

pub async fn as_thread<F: Future>(thread: Option<String>, f: F) -> F::Output
Run f as the thread a runner named on this call, when it named one. A runner that spawns one server for many conversations names each in the call’s metadata rather than in the server’s environment.