open_blockers

Function open_blockers 

pub fn open_blockers(issue: &str) -> Vec<String>
The blockers of an issue that are still open, as id (STATE), read from the tracker. Empty when the issue is workable, or when the tracker does not answer (the sitting’s doctor already said so).